package com.ruoyi.ss.deviceSuit.mapper;

import com.ruoyi.ss.deviceSuit.domain.DeviceSuit;
import com.ruoyi.ss.deviceSuit.domain.DeviceSuitQuery;
import com.ruoyi.ss.deviceSuit.domain.DeviceSuitVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 设备套餐关联Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-31
 */
public interface DeviceSuitMapper
{
    /**
     * 查询设备套餐关联
     *
     * @param id 设备套餐关联主键
     * @return 设备套餐关联
     */
    public DeviceSuitVO selectDeviceSuitById(Long id);

    /**
     * 查询设备套餐关联列表
     *
     * @param deviceSuit 设备套餐关联
     * @return 设备套餐关联集合
     */
    public List<DeviceSuitVO> selectDeviceSuitList(@Param("query")DeviceSuitQuery deviceSuit);

    /**
     * 新增设备套餐关联
     *
     * @param deviceSuit 设备套餐关联
     * @return 结果
     */
    public int insertDeviceSuit(DeviceSuit deviceSuit);

    /**
     * 修改设备套餐关联
     *
     * @param deviceSuit 设备套餐关联
     * @return 结果
     */
    public int updateDeviceSuit(@Param("data") DeviceSuit deviceSuit);

    /**
     * 删除设备套餐关联
     *
     * @param id 设备套餐关联主键
     * @return 结果
     */
    public int deleteDeviceSuitById(Long id);

    /**
     * 批量删除设备套餐关联
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDeviceSuitByIds(Long[] ids);

    /**
     * 批量新增
     */
    int batchInsert(List<DeviceSuit> list);

    /**
     * 根据套餐ID删除
     */
    int deleteBySuitIds(@Param("list") List<Long> suitIds);

    /**
     * 根据设备ID删除
     */
    int deleteByDeviceIds(@Param("list") List<Long> deviceIds);
}
