package com.ruoyi.web.controller.ss;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.deviceSuit.domain.DeviceSuit;
import com.ruoyi.ss.deviceSuit.domain.DeviceSuitVO;
import com.ruoyi.ss.deviceSuit.domain.DeviceSuitQuery;
import com.ruoyi.ss.deviceSuit.service.DeviceSuitService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 设备套餐关联Controller
 *
 * @author ruoyi
 * @date 2024-07-31
 */
@RestController
@RequestMapping("/ss/deviceSuit")
public class DeviceSuitController extends BaseController
{
    @Autowired
    private DeviceSuitService deviceSuitService;

    /**
     * 查询设备套餐关联列表
     */
    @PreAuthorize("@ss.hasPermi('ss:deviceSuit:list')")
    @GetMapping("/list")
    public TableDataInfo list(DeviceSuitQuery query)
    {
        startPage();
        startOrderBy();
        List<DeviceSuitVO> list = deviceSuitService.selectDeviceSuitList(query);
        return getDataTable(list);
    }

    /**
     * 导出设备套餐关联列表
     */
    @PreAuthorize("@ss.hasPermi('ss:deviceSuit:export')")
    @Log(title = "设备套餐关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DeviceSuitQuery query)
    {
        List<DeviceSuitVO> list = deviceSuitService.selectDeviceSuitList(query);
        ExcelUtil<DeviceSuitVO> util = new ExcelUtil<DeviceSuitVO>(DeviceSuitVO.class);
        util.exportExcel(response, list, "设备套餐关联数据");
    }

    /**
     * 获取设备套餐关联详细信息
     */
    @PreAuthorize("@ss.hasPermi('ss:deviceSuit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(deviceSuitService.selectDeviceSuitById(id));
    }

    /**
     * 新增设备套餐关联
     */
    @PreAuthorize("@ss.hasPermi('ss:deviceSuit:add')")
    @Log(title = "设备套餐关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DeviceSuit deviceSuit)
    {
        return toAjax(deviceSuitService.insertDeviceSuit(deviceSuit));
    }

    /**
     * 修改设备套餐关联
     */
    @PreAuthorize("@ss.hasPermi('ss:deviceSuit:edit')")
    @Log(title = "设备套餐关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DeviceSuit deviceSuit)
    {
        return toAjax(deviceSuitService.updateDeviceSuit(deviceSuit));
    }

    /**
     * 删除设备套餐关联
     */
    @PreAuthorize("@ss.hasPermi('ss:deviceSuit:remove')")
    @Log(title = "设备套餐关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(deviceSuitService.deleteDeviceSuitByIds(ids));
    }
}
